<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" >
  <xsl:output method="text" indent="yes" omit-xml-declaration="yes"/>
  <xsl:strip-space elements="*" />
  <xsl:template match="/dokument">
    <xsl:text>RegOSS_IM_ZO</xsl:text>
    <xsl:apply-templates select="./typ"/>
    <xsl:apply-templates select="./osoba"/>
    <xsl:apply-templates select="./identifikacia"/>
    <xsl:apply-templates select="./kontakt"/>
    <xsl:apply-templates select="./ucet"/>
    <xsl:apply-templates select="./prevadzkaEu"/>
    <xsl:apply-templates select="./predchadzajuceAAktualneCisla"/>
    <xsl:apply-templates select="./zmenaKrajinyIdentifikacie"/>
    <xsl:apply-templates select="./vyhlasenie"/>
  </xsl:template>

  <xsl:template match="/dokument/typ">
    <xsl:apply-templates select="./ziadost"/>
    <xsl:apply-templates select="./zmena"/>
  </xsl:template>
  <xsl:template match="/dokument/typ/ziadost">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>Žiadosť o registráciu (Registration request): </xsl:text><xsl:value-of select="."/>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/typ/zmena">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>Oznámenie zmeny údajov (Change of information notification): </xsl:text><xsl:value-of select="."/>
    </xsl:if>
  </xsl:template>

  <xsl:template match="/dokument/osoba">
    <xsl:apply-templates select="./fo"/>
    <xsl:apply-templates select="./po"/>
  </xsl:template>
  <xsl:template match="/dokument/osoba/fo">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>Fyzická osoba (Natural person): </xsl:text><xsl:value-of select="."/>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/osoba/po">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>Právnická osoba (Legal person): </xsl:text><xsl:value-of select="."/>
    </xsl:if>
  </xsl:template>

  <xsl:template match="/dokument/identifikacia">
    <xsl:text>&#xA;</xsl:text>
    <xsl:text>&#09;</xsl:text>
    <xsl:text>Identifikačné údaje (Identification)</xsl:text>
    <xsl:apply-templates select="./cisloIM"/>
    <xsl:apply-templates select="./zastupujeSprostredkovatel"/>
    <xsl:apply-templates select="./identCislo"/>
    <xsl:apply-templates select="./meno"/>
    <xsl:apply-templates select="./priezvisko"/>
    <xsl:apply-templates select="./rodneCislo"/>
    <xsl:apply-templates select="./datumNarodenia"/>
    <xsl:apply-templates select="./obchodneMeno"/>
    <xsl:apply-templates select="./obchodneMenoIne"/>
    <xsl:apply-templates select="./ico"/>
    <xsl:apply-templates select="./icoZahr"/>
    <xsl:apply-templates select="./krajinaSidla"/>
    <xsl:apply-templates select="./icDph"/>
    <xsl:apply-templates select="./dic"/>
  </xsl:template>
  <xsl:template match="/dokument/identifikacia/cisloIM">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>IOSS Identifikačné číslo pre DPH (IOSS VAT Identification Number (IM)): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/identifikacia/zastupujeSprostredkovatel">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>Zastúpenie sprostredkovateľom (Representation by intermediary): </xsl:text>
      <xsl:choose>
        <xsl:when test="./text()='1'">
          <xsl:text>Áno (Yes)</xsl:text>
        </xsl:when>
        <xsl:otherwise>
          <xsl:text>Nie (No)</xsl:text>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/identifikacia/identCislo">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>Evidenčné identifikačné číslo sprostredkovateľa, ak zastupuje zdaniteľnú osobu (Registration identification number of the intermediary if it represents the taxable person - Intermediary number (IN)): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/identifikacia/icDph">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>IČ DPH, ak existuje (VAT identification number): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/identifikacia/dic">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>Daňové identifikačné číslo (ak nie je IČ DPH) (Tax Identification number): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/identifikacia/meno">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>Meno (First name): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/identifikacia/priezvisko">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>Priezvisko (Last name): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/identifikacia/rodneCislo">
    <xsl:if test="./rcPredLom/text()|./rcZaLom/text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>Rodné číslo: </xsl:text><xsl:value-of select="./rcPredLom"/>/<xsl:value-of select="./rcZaLom"/>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/identifikacia/datumNarodenia">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>Dátum narodenia (Date of birth): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/identifikacia/obchodneMeno">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>Obchodný názov spoločnosti (The company name): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/identifikacia/obchodneMenoIne">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>Obchodné meno spoločnosti, ak sa líši od názvu spoločnosti (The business name of the company, if different from the company name): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/identifikacia/ico">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>IČO pridelené v tuzemsku: </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/identifikacia/icoZahr">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>IČO, ak bolo pridelené v zahraničí: </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/identifikacia/krajinaSidla">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>Krajina, v ktorej máte sídlo (The country in which you have your place of business): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>

  <xsl:template match="/dokument/kontakt">
    <xsl:text>&#xA;</xsl:text>
    <xsl:text>&#09;</xsl:text>
    <xsl:text>Kontaktné údaje zdaniteľnej osoby (Contact)</xsl:text>
    <xsl:apply-templates select="./adresa"/>
    <xsl:apply-templates select="./kontaktnaOsoba"/>
  </xsl:template>

  <xsl:template match="/dokument/kontakt/adresa">
    <xsl:text>&#xA;</xsl:text>
    <xsl:text>&#09;</xsl:text>
    <xsl:text>&#09;</xsl:text>
    <xsl:text>Adresa trvalého pobytu alebo sídla (Full postal address)</xsl:text>
    <xsl:apply-templates select="./ulica"/>
    <xsl:apply-templates select="./supisneCislo"/>
    <xsl:apply-templates select="./orientacneCislo"/>
    <xsl:apply-templates select="./psc"/>
    <xsl:apply-templates select="./mesto"/>
    <xsl:apply-templates select="./stat"/>
    <xsl:apply-templates select="./telefon"/>
    <xsl:apply-templates select="./email"/>
    <xsl:apply-templates select="./web"/>
  </xsl:template>
  <xsl:template match="/dokument/kontakt/adresa/ulica">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>Ulica (Sreet): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/kontakt/adresa/supisneCislo">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>Súpisné číslo (Number): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/kontakt/adresa/orientacneCislo">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>Orientačné číslo (Number): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/kontakt/adresa/psc">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>PSČ, ak existuje (Post Code, if exists): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/kontakt/adresa/mesto">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>Mesto (City): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/kontakt/adresa/stat">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>Štát (Country): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/kontakt/adresa/telefon">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>Telefónne číslo (Telephone number): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/kontakt/adresa/email">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>E-mail (E-mail adress): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/kontakt/adresa/web">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>Web stránka (Website): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>

  <xsl:template match="/dokument/kontakt/kontaktnaOsoba">
    <xsl:text>&#xA;</xsl:text>
    <xsl:text>&#09;</xsl:text>
    <xsl:text>&#09;</xsl:text>
    <xsl:text>Kontaktná osoba (Contact person)</xsl:text>
    <xsl:apply-templates select="./titul"/>
    <xsl:apply-templates select="./meno"/>
    <xsl:apply-templates select="./stredneMeno"/>
    <xsl:apply-templates select="./priezvisko"/>
  </xsl:template>
  <xsl:template match="/dokument/kontakt/kontaktnaOsoba/titul">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>Oslovenie (Title): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/kontakt/kontaktnaOsoba/meno">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>Meno (First name): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/kontakt/kontaktnaOsoba/stredneMeno">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>Stredné meno (Middle name): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/kontakt/kontaktnaOsoba/priezvisko">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>Priezvisko (Last name): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>

  <xsl:template match="/dokument/ucet">
    <xsl:text>&#xA;</xsl:text>
    <xsl:text>&#09;</xsl:text>
    <xsl:text>Bankové informácie (Bank Account Information)</xsl:text>
    <xsl:apply-templates select="./iban"/>
    <xsl:apply-templates select="./bic"/>
    <xsl:apply-templates select="./vlastnikUctu"/>
  </xsl:template>
  <xsl:template match="/dokument/ucet/iban">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>IBAN (IBAN number): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/ucet/bic">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>BIC (BIC number): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/ucet/vlastnikUctu">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>Vlastník účtu (Account Holder): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>

  <xsl:template match="/dokument/prevadzkaEu">
    <xsl:text>&#xA;</xsl:text>
    <xsl:text>&#09;</xsl:text>
    <xsl:text>Prevádzkarne v iných krajinách EÚ (Fixed establishments in other EU countries)</xsl:text>
    <xsl:apply-templates select="./krajinaIcDph"/>
    <xsl:apply-templates select="./icDph"/>
    <xsl:apply-templates select="./dic"/>
    <xsl:apply-templates select="./obchodneMeno"/>
    <xsl:apply-templates select="./ulica"/>
    <xsl:apply-templates select="./supisneCislo"/>
    <xsl:apply-templates select="./orientacneCislo"/>
    <xsl:apply-templates select="./psc"/>
    <xsl:apply-templates select="./mesto"/>
    <xsl:apply-templates select="./stat"/>
  </xsl:template>
  <xsl:template match="/dokument/prevadzkaEu/krajinaIcDph">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>Krajina, ktorá pridelila IČ DPH (Issuing Country): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/prevadzkaEu/icDph">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>IČ DPH (VAT Identification Number): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/prevadzkaEu/dic">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>Daňové identifikačné číslo (ak nie je IČ DPH) (Identification number (if no VAT ID Number)): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/prevadzkaEu/obchodneMeno">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>Obchodné meno (The trading name): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/prevadzkaEu/ulica">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>Ulica (Sreet): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/prevadzkaEu/supisneCislo">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>Súpisné číslo (Number): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/prevadzkaEu/orientacneCislo">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>Orientačné číslo (Number): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/prevadzkaEu/psc">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>PSČ, ak existuje (Post Code, if exists): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/prevadzkaEu/mesto">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>Mesto (City): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/prevadzkaEu/stat">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>Štát (Country): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>

  <xsl:template match="/dokument/zmenaKrajinyIdentifikacie">
    <xsl:text>&#xA;</xsl:text>
    <xsl:text>&#09;</xsl:text>
    <xsl:text>Zmena krajiny identifikácie - okrem nového ČŠI (SR) (Change country of identification-except for new ČŠI (SR))</xsl:text>
    <xsl:apply-templates select="./krajinaIcDph"/>
    <xsl:apply-templates select="./icDph"/>
    <xsl:apply-templates select="./datumZmeny"/>
  </xsl:template>
  <xsl:template match="/dokument/zmenaKrajinyIdentifikacie/krajinaIcDph">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>Krajina, ktorá pridelila IČ DPH (Issuing Country): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/zmenaKrajinyIdentifikacie/icDph">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>IČ DPH (VAT Identification Number): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/zmenaKrajinyIdentifikacie/datumZmeny">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>Dátum, kedy došlo k zmene (Date when the change occurred): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>

  <xsl:template match="/dokument/predchadzajuceAAktualneCisla">
    <xsl:text>&#xA;</xsl:text>
    <xsl:text>&#09;</xsl:text>
    <xsl:text>Predchádzajúce alebo aktuálne používané individuálne identifikačné čísla, resp. čísla pre DPH pridelené členským štátom identifikácie v súlade s článkom 362, 369d alebo 369q smernice 2006/112/ES, ak zdaniteľná osoba predtým využívala alebo v súčasnosti využíva niektorú z týchto úprav(Previously used or is currently using individual VAT identification number(s) allocated by the Member State of identification in accordance with Articles 362, 369d or 369q of Directive 2006/112/EC if the taxable person has previously used or is currently using one of these schemes)</xsl:text>
    <xsl:apply-templates select="./krajinaIcDph"/>
    <xsl:apply-templates select="./icDph"/>
  </xsl:template>
  <xsl:template match="/dokument/predchadzajuceAAktualneCisla/krajinaIcDph">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>Krajina, ktorá pridelila IČ DPH (Issuing Country): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/predchadzajuceAAktualneCisla/icDph">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>Identifikačné číslo (VAT Identification Number): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>
  
  <xsl:template match="/dokument/vyhlasenie">
    <xsl:text>&#xA;</xsl:text>
    <xsl:text>&#09;</xsl:text>
    <xsl:text>Vyhlásenie (Declaration)</xsl:text>
    <xsl:apply-templates select="./pravdiveUdaje"/>
    <xsl:apply-templates select="./datumZiadosti"/>
  </xsl:template>
  <xsl:template match="/dokument/vyhlasenie/pravdiveUdaje">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>Potvrdzujem, že informácie uvedené v tomto formulári sú pravdivé, úplné a presné (By ticking this box, I confirm that the information given in this form is true, complete and accurate): </xsl:text><xsl:value-of select="."/>
    </xsl:if>
  </xsl:template>
  <xsl:template match="/dokument/vyhlasenie/datumZiadosti">
    <xsl:if test="./text()">
      <xsl:text>&#xA;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>&#09;</xsl:text>
      <xsl:text>Dátum žiadosti (Date of application): </xsl:text>
      <xsl:call-template name="string-replace-all">
        <xsl:with-param name="text" select="." />
        <xsl:with-param name="replace" select="'&#10;'" />
        <xsl:with-param name="by" select="'&#13;&#10;&#09;&#09;'" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>

  <xsl:template name="string-replace-all">
    <xsl:param name="text"/>
    <xsl:param name="replace"/>
    <xsl:param name="by"/>
    <xsl:choose>
      <xsl:when test="contains($text, $replace)">
        <xsl:value-of select="substring-before($text,$replace)"/>
        <xsl:value-of select="$by"/>
        <xsl:call-template name="string-replace-all">
          <xsl:with-param name="text" select="substring-after($text,$replace)"/>
          <xsl:with-param name="replace" select="$replace"/>
          <xsl:with-param name="by" select="$by" />
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$text"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
</xsl:stylesheet>